Job

Struct Job 

pub struct Job {
Show 30 fields pub id: u32, pub script: Option<Box<PathBuf>>, pub command: Option<CompactString>, pub gpus: u32, pub conda_env: Option<CompactString>, pub run_dir: PathBuf, pub priority: u8, pub depends_on: Option<u32>, pub depends_on_ids: DependencyIds, pub dependency_mode: Option<DependencyMode>, pub auto_cancel_on_dependency_failure: bool, pub task_id: Option<u32>, pub gpu_sharing_mode: GpuSharingMode, pub gpu_memory_limit_mb: Option<u64>, pub time_limit: Option<Duration>, pub memory_limit_mb: Option<u64>, pub submitted_by: CompactString, pub redone_from: Option<u32>, pub auto_close_tmux: bool, pub parameters: Parameters, pub group_id: Option<Uuid>, pub max_concurrent: Option<usize>, pub run_name: Option<CompactString>, pub project: Option<CompactString>, pub state: JobState, pub gpu_ids: Option<GpuIds>, pub submitted_at: Option<SystemTime>, pub started_at: Option<SystemTime>, pub finished_at: Option<SystemTime>, pub reason: Option<Box<JobStateReason>>,
}

Fields

id: u32

Required fields at submission time

script: Option<Box<PathBuf>>command: Option<CompactString>gpus: u32conda_env: Option<CompactString>run_dir: PathBufpriority: u8depends_on: Option<u32>depends_on_ids: DependencyIdsdependency_mode: Option<DependencyMode>auto_cancel_on_dependency_failure: booltask_id: Option<u32>gpu_sharing_mode: GpuSharingModegpu_memory_limit_mb: Option<u64>time_limit: Option<Duration>memory_limit_mb: Option<u64>submitted_by: CompactStringredone_from: Option<u32>auto_close_tmux: boolparameters: Parametersgroup_id: Option<Uuid>max_concurrent: Option<usize>run_name: Option<CompactString>

Optional fields that get populated by gflowd

project: Option<CompactString>state: JobStategpu_ids: Option<GpuIds>submitted_at: Option<SystemTime>started_at: Option<SystemTime>finished_at: Option<SystemTime>reason: Option<Box<JobStateReason>>

Implementations

Source

impl Job

pub fn builder() -> JobBuilder

pub fn from_parts(spec: JobSpec, runtime: JobRuntime) -> Self

Create a Job from separate JobSpec and JobRuntime components

pub fn into_parts(self) -> (JobSpec, JobRuntime)

Split a Job into separate JobSpec and JobRuntime components

pub fn all_dependency_ids(&self) -> DependencyIds

Returns all dependency IDs (combining legacy single dependency and new multi-dependency)

pub fn dependency_ids_iter(&self) -> impl Iterator<Item = u32> + '_

Returns an iterator over all dependency IDs without allocation. The legacy depends_on is yielded first (if present and not in depends_on_ids), followed by all IDs in depends_on_ids.

pub fn has_no_dependencies(&self) -> bool

Returns true if this job has no dependencies.

pub fn transition_to(&mut self, next: JobState) -> Result<(), JobError>

pub fn try_transition(&mut self, job_id: u32, next: JobState) -> bool

pub fn has_exceeded_time_limit(&self) -> bool

Check if the job has exceeded its time limit

pub fn wait_time(&self) -> Option<Duration>

Calculate wait time (time from submission to start)

pub fn runtime(&self) -> Option<Duration>

Calculate runtime (time from start to finish, or current elapsed time if still running)