Module paths

Module paths 

Functions

get_config_dir
get_daemon_log_file_path
get_data_dir
get_log_file_path
Returns the log file path for a job without any side effects.
get_runtime_dir
prepare_log_file_path
Returns the log file path for a job, archiving any existing log first. Only call this when starting a new job execution to avoid losing active logs.