pub struct Client { /* private fields */ }Implementations
Sourceimpl Client
impl Client
pub fn build(config: &Config) -> Result<Self>
Sourcepub async fn list_jobs(&self) -> Result<Vec<Job>>
pub async fn list_jobs(&self) -> Result<Vec<Job>>
List jobs with optional query parameters.
If no parameters are provided, returns jobs from memory (active jobs only). If parameters are provided, queries from database with pagination support.
Sourcepub async fn list_jobs_with_query(
&self,
states: Option<String>,
user: Option<String>,
limit: Option<usize>,
offset: Option<usize>,
created_after: Option<i64>,
) -> Result<Vec<Job>>
pub async fn list_jobs_with_query( &self, states: Option<String>, user: Option<String>, limit: Option<usize>, offset: Option<usize>, created_after: Option<i64>, ) -> Result<Vec<Job>>
List jobs with query parameters for database queries.
This method queries from the database and supports:
- State filtering (e.g., “Running,Finished”)
- User filtering (e.g., “user1,user2”)
- Pagination (limit and offset)
- Time filtering (created_after timestamp)
Returns all matching jobs from the database, not just in-memory jobs.
pub async fn get_job(&self, job_id: u32) -> Result<Option<Job>>
pub async fn add_job(&self, job: Job) -> Result<JobSubmitResponse>
Sourcepub async fn add_jobs(&self, jobs: Vec<Job>) -> Result<Vec<JobSubmitResponse>>
pub async fn add_jobs(&self, jobs: Vec<Job>) -> Result<Vec<JobSubmitResponse>>
Submit multiple jobs in a batch
pub async fn finish_job(&self, job_id: u32) -> Result<()>
pub async fn fail_job(&self, job_id: u32) -> Result<()>
pub async fn cancel_job(&self, job_id: u32) -> Result<()>
pub async fn hold_job(&self, job_id: u32) -> Result<()>
pub async fn release_job(&self, job_id: u32) -> Result<()>
pub async fn update_job( &self, job_id: u32, request: UpdateJobRequest, ) -> Result<UpdateJobResponse>
pub async fn get_job_log_path(&self, job_id: u32) -> Result<Option<String>>
pub async fn get_stats( &self, user: Option<&str>, since: Option<i64>, ) -> Result<UsageStats>
pub async fn get_info(&self) -> Result<SchedulerInfo>
pub async fn get_health(&self) -> Result<StatusCode>
pub async fn get_health_with_pid(&self) -> Result<Option<u32>>
pub async fn resolve_dependency( &self, username: &str, shorthand: &str, ) -> Result<u32>
pub async fn set_allowed_gpus( &self, allowed_indices: Option<Vec<u32>>, ) -> Result<()>
pub async fn set_group_max_concurrency( &self, group_id: &str, max_concurrent: usize, ) -> Result<usize>
Sourcepub async fn create_reservation(
&self,
user: String,
gpu_spec: GpuSpec,
start_time: SystemTime,
duration_secs: u64,
) -> Result<u32>
pub async fn create_reservation( &self, user: String, gpu_spec: GpuSpec, start_time: SystemTime, duration_secs: u64, ) -> Result<u32>
Create a GPU reservation
Sourcepub async fn list_reservations(
&self,
user: Option<String>,
status: Option<String>,
active_only: bool,
) -> Result<Vec<GpuReservation>>
pub async fn list_reservations( &self, user: Option<String>, status: Option<String>, active_only: bool, ) -> Result<Vec<GpuReservation>>
List GPU reservations
Sourcepub async fn get_reservation(&self, id: u32) -> Result<Option<GpuReservation>>
pub async fn get_reservation(&self, id: u32) -> Result<Option<GpuReservation>>
Get a specific GPU reservation by ID
Sourcepub async fn cancel_reservation(&self, id: u32) -> Result<()>
pub async fn cancel_reservation(&self, id: u32) -> Result<()>
Cancel a GPU reservation