Functions
- get_
config_ dir - get_
daemon_ log_ file_ path - get_
data_ dir - get_
log_ file_ path - Returns the log file path for a job without any side effects.
- get_
runtime_ dir - prepare_
log_ file_ path - Returns the log file path for a job, archiving any existing log first. Only call this when starting a new job execution to avoid losing active logs.